# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from y2 import Y2, AsyncY2
from y2.types import (
    NewsListResponse,
    NewsGetRecapsResponse,
    NewsListFeedsResponse,
)
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestNews:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Y2) -> None:
        news = client.news.list()
        assert_matches_type(NewsListResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Y2) -> None:
        news = client.news.list(
            limit=1,
            topics="crypto,ai_agents,bitcoin",
        )
        assert_matches_type(NewsListResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Y2) -> None:
        response = client.news.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        news = response.parse()
        assert_matches_type(NewsListResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Y2) -> None:
        with client.news.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            news = response.parse()
            assert_matches_type(NewsListResponse, news, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_recaps(self, client: Y2) -> None:
        news = client.news.get_recaps()
        assert_matches_type(NewsGetRecapsResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_recaps_with_all_params(self, client: Y2) -> None:
        news = client.news.get_recaps(
            timeframe="12h",
            topics="topics",
        )
        assert_matches_type(NewsGetRecapsResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_recaps(self, client: Y2) -> None:
        response = client.news.with_raw_response.get_recaps()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        news = response.parse()
        assert_matches_type(NewsGetRecapsResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_recaps(self, client: Y2) -> None:
        with client.news.with_streaming_response.get_recaps() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            news = response.parse()
            assert_matches_type(NewsGetRecapsResponse, news, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_feeds(self, client: Y2) -> None:
        news = client.news.list_feeds()
        assert_matches_type(NewsListFeedsResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_feeds(self, client: Y2) -> None:
        response = client.news.with_raw_response.list_feeds()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        news = response.parse()
        assert_matches_type(NewsListFeedsResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_feeds(self, client: Y2) -> None:
        with client.news.with_streaming_response.list_feeds() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            news = response.parse()
            assert_matches_type(NewsListFeedsResponse, news, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncNews:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncY2) -> None:
        news = await async_client.news.list()
        assert_matches_type(NewsListResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncY2) -> None:
        news = await async_client.news.list(
            limit=1,
            topics="crypto,ai_agents,bitcoin",
        )
        assert_matches_type(NewsListResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncY2) -> None:
        response = await async_client.news.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        news = await response.parse()
        assert_matches_type(NewsListResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncY2) -> None:
        async with async_client.news.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            news = await response.parse()
            assert_matches_type(NewsListResponse, news, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_recaps(self, async_client: AsyncY2) -> None:
        news = await async_client.news.get_recaps()
        assert_matches_type(NewsGetRecapsResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_recaps_with_all_params(self, async_client: AsyncY2) -> None:
        news = await async_client.news.get_recaps(
            timeframe="12h",
            topics="topics",
        )
        assert_matches_type(NewsGetRecapsResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_recaps(self, async_client: AsyncY2) -> None:
        response = await async_client.news.with_raw_response.get_recaps()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        news = await response.parse()
        assert_matches_type(NewsGetRecapsResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_recaps(self, async_client: AsyncY2) -> None:
        async with async_client.news.with_streaming_response.get_recaps() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            news = await response.parse()
            assert_matches_type(NewsGetRecapsResponse, news, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_feeds(self, async_client: AsyncY2) -> None:
        news = await async_client.news.list_feeds()
        assert_matches_type(NewsListFeedsResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_feeds(self, async_client: AsyncY2) -> None:
        response = await async_client.news.with_raw_response.list_feeds()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        news = await response.parse()
        assert_matches_type(NewsListFeedsResponse, news, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_feeds(self, async_client: AsyncY2) -> None:
        async with async_client.news.with_streaming_response.list_feeds() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            news = await response.parse()
            assert_matches_type(NewsListFeedsResponse, news, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["AudioMetadata"]


class AudioMetadata(BaseModel):
    duration: Optional[float] = None
    """Duration in seconds"""

    duration_formatted: Optional[str] = FieldInfo(alias="durationFormatted", default=None)
    """Duration as HH:MM:SS"""

    file_size: Optional[int] = FieldInfo(alias="fileSize", default=None)
    """File size in bytes"""

    format: Optional[Literal["mp3"]] = None

    mime_type: Optional[Literal["audio/mpeg"]] = FieldInfo(alias="mimeType", default=None)

    storage_id: Optional[str] = FieldInfo(alias="storageId", default=None)
    """Convex storage ID for internal reference"""

    url: Optional[str] = None
    """CDN URL for audio file"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["NewsListParams"]


class NewsListParams(TypedDict, total=False):
    limit: int
    """Maximum number of items to return"""

    topics: str
    """
    Comma-separated list of topics to filter by. Valid topics: ai, ai_agents, aptos,
    base, bitcoin, crypto, dats, defi, ethereum, hyperliquid, machine_learning,
    macro, ondo, perps, ripple, rwa, solana, tech, virtuals. Default: crypto,
    ai_agents, macro, bitcoin, ethereum, tech
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .audio_metadata import AudioMetadata

__all__ = ["ReportRetrieveAudioResponse"]


class ReportRetrieveAudioResponse(BaseModel):
    data: Optional[AudioMetadata] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["TopicEnum"]

TopicEnum: TypeAlias = Literal[
    "ai",
    "ai_agents",
    "aptos",
    "base",
    "bitcoin",
    "crypto",
    "dats",
    "defi",
    "ethereum",
    "hyperliquid",
    "machine_learning",
    "macro",
    "ondo",
    "perps",
    "ripple",
    "rwa",
    "solana",
    "tech",
    "virtuals",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["TimeframeEnum"]

TimeframeEnum: TypeAlias = Literal["12h", "24h", "3d", "7d"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .audio_metadata import AudioMetadata

__all__ = [
    "ReportRetrieveResponse",
    "Data",
    "DataContent",
    "DataMetadata",
    "DataMetadataFreshnessMetadata",
    "DataMetadataRecursionMetadata",
]


class DataContent(BaseModel):
    html: Optional[str] = None
    """Full HTML content"""

    summary: Optional[str] = None
    """SMS-friendly summary"""


class DataMetadataFreshnessMetadata(BaseModel):
    """Source freshness validation results"""

    accessible_links: Optional[int] = FieldInfo(alias="accessibleLinks", default=None)

    average_age_ms: Optional[int] = FieldInfo(alias="averageAgeMs", default=None)
    """Average source age in milliseconds"""

    freshness_score: Optional[float] = FieldInfo(alias="freshnessScore", default=None)
    """Overall freshness score (higher = fresher)"""

    stale_sources_count: Optional[int] = FieldInfo(alias="staleSourcesCount", default=None)

    total_links: Optional[int] = FieldInfo(alias="totalLinks", default=None)

    validated_at: Optional[int] = FieldInfo(alias="validatedAt", default=None)


class DataMetadataRecursionMetadata(BaseModel):
    """Metadata about recursive research execution"""

    depth: Optional[int] = None
    """Recursion depth achieved (0 = standard report)"""

    fallback_reason: Optional[str] = FieldInfo(alias="fallbackReason", default=None)
    """Reason if fallback to standard generation occurred"""

    layers_processed: Optional[int] = FieldInfo(alias="layersProcessed", default=None)

    strategy: Optional[Literal["breadth-first", "depth-first", "hybrid"]] = None

    subtopics_generated: Optional[List[str]] = FieldInfo(alias="subtopicsGenerated", default=None)

    total_sources_collected: Optional[int] = FieldInfo(alias="totalSourcesCollected", default=None)

    total_time_ms: Optional[int] = FieldInfo(alias="totalTimeMs", default=None)

    unique_sources_aggregated: Optional[int] = FieldInfo(alias="uniqueSourcesAggregated", default=None)


class DataMetadata(BaseModel):
    freshness_metadata: Optional[DataMetadataFreshnessMetadata] = FieldInfo(alias="freshnessMetadata", default=None)
    """Source freshness validation results"""

    model: Optional[str] = None

    recursion_metadata: Optional[DataMetadataRecursionMetadata] = FieldInfo(alias="recursionMetadata", default=None)
    """Metadata about recursive research execution"""

    total_cost: Optional[float] = FieldInfo(alias="totalCost", default=None)


class Data(BaseModel):
    id: str

    content: DataContent

    generated_at: int = FieldInfo(alias="generatedAt")

    generated_at_iso: datetime = FieldInfo(alias="generatedAtISO")

    profile_id: str = FieldInfo(alias="profileId")

    audio: Optional[AudioMetadata] = None

    metadata: Optional[DataMetadata] = None

    profile_name: Optional[str] = FieldInfo(alias="profileName", default=None)

    profile_topic: Optional[str] = FieldInfo(alias="profileTopic", default=None)

    sources: Optional[List[str]] = None

    topic: Optional[str] = None


class ReportRetrieveResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ReportRetrieveAudioParams"]


class ReportRetrieveAudioParams(TypedDict, total=False):
    redirect: bool
    """If true, returns 302 redirect to audio CDN URL"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from .._models import BaseModel
from .topic_enum import TopicEnum
from .timeframe_enum import TimeframeEnum

__all__ = ["NewsGetRecapsResponse", "Meta"]


class Meta(BaseModel):
    timeframe: Optional[TimeframeEnum] = None
    """Time period for recap data"""

    topics: Optional[List[TopicEnum]] = None


class NewsGetRecapsResponse(BaseModel):
    data: Dict[str, object]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import TimeframeEnum, news_list_params, news_get_recaps_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.timeframe_enum import TimeframeEnum
from ..types.news_list_response import NewsListResponse
from ..types.news_get_recaps_response import NewsGetRecapsResponse
from ..types.news_list_feeds_response import NewsListFeedsResponse

__all__ = ["NewsResource", "AsyncNewsResource"]


class NewsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> NewsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/y2-intel/y2-py#accessing-raw-response-data-eg-headers
        """
        return NewsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> NewsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/y2-intel/y2-py#with_streaming_response
        """
        return NewsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        limit: int | Omit = omit,
        topics: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> NewsListResponse:
        """Returns news items from the GloriaAI terminal cache.

        Supports filtering by
        topics and pagination.

        Args:
          limit: Maximum number of items to return

          topics: Comma-separated list of topics to filter by. Valid topics: ai, ai_agents, aptos,
              base, bitcoin, crypto, dats, defi, ethereum, hyperliquid, machine_learning,
              macro, ondo, perps, ripple, rwa, solana, tech, virtuals. Default: crypto,
              ai_agents, macro, bitcoin, ethereum, tech

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/news",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "topics": topics,
                    },
                    news_list_params.NewsListParams,
                ),
            ),
            cast_to=NewsListResponse,
        )

    def get_recaps(
        self,
        *,
        timeframe: TimeframeEnum | Omit = omit,
        topics: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> NewsGetRecapsResponse:
        """
        Returns AI-generated recap summaries for specified topics within a given
        timeframe.

        Args:
          timeframe: Time period for recaps

          topics: Comma-separated list of topics. Valid topics: ai, ai_agents, aptos, base,
              bitcoin, crypto, dats, defi, ethereum, hyperliquid, machine_learning, macro,
              ondo, perps, ripple, rwa, solana, tech, virtuals

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/news/recaps",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "timeframe": timeframe,
                        "topics": topics,
                    },
                    news_get_recaps_params.NewsGetRecapsParams,
                ),
            ),
            cast_to=NewsGetRecapsResponse,
        )

    def list_feeds(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> NewsListFeedsResponse:
        """Returns all available news feed topics with descriptions."""
        return self._get(
            "/news/feeds",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NewsListFeedsResponse,
        )


class AsyncNewsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncNewsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/y2-intel/y2-py#accessing-raw-response-data-eg-headers
        """
        return AsyncNewsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncNewsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/y2-intel/y2-py#with_streaming_response
        """
        return AsyncNewsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        limit: int | Omit = omit,
        topics: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> NewsListResponse:
        """Returns news items from the GloriaAI terminal cache.

        Supports filtering by
        topics and pagination.

        Args:
          limit: Maximum number of items to return

          topics: Comma-separated list of topics to filter by. Valid topics: ai, ai_agents, aptos,
              base, bitcoin, crypto, dats, defi, ethereum, hyperliquid, machine_learning,
              macro, ondo, perps, ripple, rwa, solana, tech, virtuals. Default: crypto,
              ai_agents, macro, bitcoin, ethereum, tech

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/news",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "topics": topics,
                    },
                    news_list_params.NewsListParams,
                ),
            ),
            cast_to=NewsListResponse,
        )

    async def get_recaps(
        self,
        *,
        timeframe: TimeframeEnum | Omit = omit,
        topics: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> NewsGetRecapsResponse:
        """
        Returns AI-generated recap summaries for specified topics within a given
        timeframe.

        Args:
          timeframe: Time period for recaps

          topics: Comma-separated list of topics. Valid topics: ai, ai_agents, aptos, base,
              bitcoin, crypto, dats, defi, ethereum, hyperliquid, machine_learning, macro,
              ondo, perps, ripple, rwa, solana, tech, virtuals

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/news/recaps",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "timeframe": timeframe,
                        "topics": topics,
                    },
                    news_get_recaps_params.NewsGetRecapsParams,
                ),
            ),
            cast_to=NewsGetRecapsResponse,
        )

    async def list_feeds(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> NewsListFeedsResponse:
        """Returns all available news feed topics with descriptions."""
        return await self._get(
            "/news/feeds",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NewsListFeedsResponse,
        )


class NewsResourceWithRawResponse:
    def __init__(self, news: NewsResource) -> None:
        self._news = news

        self.list = to_raw_response_wrapper(
            news.list,
        )
        self.get_recaps = to_raw_response_wrapper(
            news.get_recaps,
        )
        self.list_feeds = to_raw_response_wrapper(
            news.list_feeds,
        )


class AsyncNewsResourceWithRawResponse:
    def __init__(self, news: AsyncNewsResource) -> None:
        self._news = news

        self.list = async_to_raw_response_wrapper(
            news.list,
        )
        self.get_recaps = async_to_raw_response_wrapper(
            news.get_recaps,
        )
        self.list_feeds = async_to_raw_response_wrapper(
            news.list_feeds,
        )


class NewsResourceWithStreamingResponse:
    def __init__(self, news: NewsResource) -> None:
        self._news = news

        self.list = to_streamed_response_wrapper(
            news.list,
        )
        self.get_recaps = to_streamed_response_wrapper(
            news.get_recaps,
        )
        self.list_feeds = to_streamed_response_wrapper(
            news.list_feeds,
        )


class AsyncNewsResourceWithStreamingResponse:
    def __init__(self, news: AsyncNewsResource) -> None:
        self._news = news

        self.list = async_to_streamed_response_wrapper(
            news.list,
        )
        self.get_recaps = async_to_streamed_response_wrapper(
            news.get_recaps,
        )
        self.list_feeds = async_to_streamed_response_wrapper(
            news.list_feeds,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["ReportListResponse", "Data", "Meta"]


class Data(BaseModel):
    id: str
    """Report ID (Convex document ID)"""

    generated_at: int = FieldInfo(alias="generatedAt")
    """Unix timestamp (milliseconds)"""

    generated_at_iso: datetime = FieldInfo(alias="generatedAtISO")
    """ISO 8601 timestamp"""

    profile_id: str = FieldInfo(alias="profileId")
    """Profile ID this report belongs to"""

    has_audio: Optional[bool] = FieldInfo(alias="hasAudio", default=None)
    """Whether audio narration is available"""

    model: Optional[str] = None
    """LLM model used for generation"""

    summary: Optional[str] = None
    """Brief SMS-friendly summary"""

    topic: Optional[str] = None
    """Report topic"""


class Meta(BaseModel):
    count: Optional[int] = None

    limit: Optional[int] = None


class ReportListResponse(BaseModel):
    data: List[Data]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

from .timeframe_enum import TimeframeEnum

__all__ = ["NewsGetRecapsParams"]


class NewsGetRecapsParams(TypedDict, total=False):
    timeframe: TimeframeEnum
    """Time period for recaps"""

    topics: str
    """
    Comma-separated list of topics. Valid topics: ai, ai_agents, aptos, base,
    bitcoin, crypto, dats, defi, ethereum, hyperliquid, machine_learning, macro,
    ondo, perps, ripple, rwa, solana, tech, virtuals
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["ProfileListResponse", "Data", "DataProfile", "Meta"]


class DataProfile(BaseModel):
    audio_enabled: Optional[bool] = FieldInfo(alias="audioEnabled", default=None)

    frequency: Optional[str] = None

    name: Optional[str] = None

    status: Optional[str] = None

    topic: Optional[str] = None


class Data(BaseModel):
    delivery_method: Literal["email", "sms", "webhook", "both_email_sms"] = FieldInfo(alias="deliveryMethod")

    is_active: bool = FieldInfo(alias="isActive")

    profile_id: str = FieldInfo(alias="profileId")

    subscribed_at: int = FieldInfo(alias="subscribedAt")

    subscription_id: str = FieldInfo(alias="subscriptionId")

    profile: Optional[DataProfile] = None


class Meta(BaseModel):
    count: Optional[int] = None


class ProfileListResponse(BaseModel):
    data: List[Data]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .topic_enum import TopicEnum

__all__ = ["NewsListFeedsResponse", "Data", "Meta"]


class Data(BaseModel):
    id: TopicEnum
    """Available news feed topics from GloriaAI"""

    name: str
    """Human-readable name"""

    description: Optional[str] = None
    """Feed description"""


class Meta(BaseModel):
    count: Optional[int] = None


class NewsListFeedsResponse(BaseModel):
    data: List[Data]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ReportListParams"]


class ReportListParams(TypedDict, total=False):
    limit: int
    """Maximum number of reports to return"""

    profile_id: Annotated[str, PropertyInfo(alias="profileId")]
    """Filter reports by profile ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .topic_enum import TopicEnum as TopicEnum
from .audio_metadata import AudioMetadata as AudioMetadata
from .timeframe_enum import TimeframeEnum as TimeframeEnum
from .news_list_params import NewsListParams as NewsListParams
from .news_list_response import NewsListResponse as NewsListResponse
from .report_list_params import ReportListParams as ReportListParams
from .report_list_response import ReportListResponse as ReportListResponse
from .profile_list_response import ProfileListResponse as ProfileListResponse
from .news_get_recaps_params import NewsGetRecapsParams as NewsGetRecapsParams
from .news_get_recaps_response import NewsGetRecapsResponse as NewsGetRecapsResponse
from .news_list_feeds_response import NewsListFeedsResponse as NewsListFeedsResponse
from .report_retrieve_response import ReportRetrieveResponse as ReportRetrieveResponse
from .report_retrieve_audio_params import ReportRetrieveAudioParams as ReportRetrieveAudioParams
from .report_retrieve_audio_response import ReportRetrieveAudioResponse as ReportRetrieveAudioResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import report_list_params, report_retrieve_audio_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.report_list_response import ReportListResponse
from ..types.report_retrieve_response import ReportRetrieveResponse
from ..types.report_retrieve_audio_response import ReportRetrieveAudioResponse

__all__ = ["ReportsResource", "AsyncReportsResource"]


class ReportsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ReportsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/y2-intel/y2-py#accessing-raw-response-data-eg-headers
        """
        return ReportsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ReportsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/y2-intel/y2-py#with_streaming_response
        """
        return ReportsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        report_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReportRetrieveResponse:
        """
        Returns the full content of a specific intelligence report, including HTML
        content, sources, and audio metadata.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not report_id:
            raise ValueError(f"Expected a non-empty value for `report_id` but received {report_id!r}")
        return self._get(
            f"/reports/{report_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ReportRetrieveResponse,
        )

    def list(
        self,
        *,
        limit: int | Omit = omit,
        profile_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReportListResponse:
        """Returns a list of reports for the user's subscribed profiles.

        Results are sorted
        by generation date (newest first).

        Args:
          limit: Maximum number of reports to return

          profile_id: Filter reports by profile ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/reports",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "profile_id": profile_id,
                    },
                    report_list_params.ReportListParams,
                ),
            ),
            cast_to=ReportListResponse,
        )

    def retrieve_audio(
        self,
        report_id: str,
        *,
        redirect: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReportRetrieveAudioResponse:
        """Returns audio file metadata or redirects to the CDN URL.

        Requires the
        `reports:audio` scope.

        Args:
          redirect: If true, returns 302 redirect to audio CDN URL

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not report_id:
            raise ValueError(f"Expected a non-empty value for `report_id` but received {report_id!r}")
        return self._get(
            f"/reports/{report_id}/audio",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"redirect": redirect}, report_retrieve_audio_params.ReportRetrieveAudioParams),
            ),
            cast_to=ReportRetrieveAudioResponse,
        )


class AsyncReportsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncReportsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/y2-intel/y2-py#accessing-raw-response-data-eg-headers
        """
        return AsyncReportsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncReportsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/y2-intel/y2-py#with_streaming_response
        """
        return AsyncReportsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        report_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReportRetrieveResponse:
        """
        Returns the full content of a specific intelligence report, including HTML
        content, sources, and audio metadata.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not report_id:
            raise ValueError(f"Expected a non-empty value for `report_id` but received {report_id!r}")
        return await self._get(
            f"/reports/{report_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ReportRetrieveResponse,
        )

    async def list(
        self,
        *,
        limit: int | Omit = omit,
        profile_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReportListResponse:
        """Returns a list of reports for the user's subscribed profiles.

        Results are sorted
        by generation date (newest first).

        Args:
          limit: Maximum number of reports to return

          profile_id: Filter reports by profile ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/reports",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "profile_id": profile_id,
                    },
                    report_list_params.ReportListParams,
                ),
            ),
            cast_to=ReportListResponse,
        )

    async def retrieve_audio(
        self,
        report_id: str,
        *,
        redirect: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReportRetrieveAudioResponse:
        """Returns audio file metadata or redirects to the CDN URL.

        Requires the
        `reports:audio` scope.

        Args:
          redirect: If true, returns 302 redirect to audio CDN URL

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not report_id:
            raise ValueError(f"Expected a non-empty value for `report_id` but received {report_id!r}")
        return await self._get(
            f"/reports/{report_id}/audio",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"redirect": redirect}, report_retrieve_audio_params.ReportRetrieveAudioParams
                ),
            ),
            cast_to=ReportRetrieveAudioResponse,
        )


class ReportsResourceWithRawResponse:
    def __init__(self, reports: ReportsResource) -> None:
        self._reports = reports

        self.retrieve = to_raw_response_wrapper(
            reports.retrieve,
        )
        self.list = to_raw_response_wrapper(
            reports.list,
        )
        self.retrieve_audio = to_raw_response_wrapper(
            reports.retrieve_audio,
        )


class AsyncReportsResourceWithRawResponse:
    def __init__(self, reports: AsyncReportsResource) -> None:
        self._reports = reports

        self.retrieve = async_to_raw_response_wrapper(
            reports.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            reports.list,
        )
        self.retrieve_audio = async_to_raw_response_wrapper(
            reports.retrieve_audio,
        )


class ReportsResourceWithStreamingResponse:
    def __init__(self, reports: ReportsResource) -> None:
        self._reports = reports

        self.retrieve = to_streamed_response_wrapper(
            reports.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            reports.list,
        )
        self.retrieve_audio = to_streamed_response_wrapper(
            reports.retrieve_audio,
        )


class AsyncReportsResourceWithStreamingResponse:
    def __init__(self, reports: AsyncReportsResource) -> None:
        self._reports = reports

        self.retrieve = async_to_streamed_response_wrapper(
            reports.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            reports.list,
        )
        self.retrieve_audio = async_to_streamed_response_wrapper(
            reports.retrieve_audio,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .news import (
    NewsResource,
    AsyncNewsResource,
    NewsResourceWithRawResponse,
    AsyncNewsResourceWithRawResponse,
    NewsResourceWithStreamingResponse,
    AsyncNewsResourceWithStreamingResponse,
)
from .reports import (
    ReportsResource,
    AsyncReportsResource,
    ReportsResourceWithRawResponse,
    AsyncReportsResourceWithRawResponse,
    ReportsResourceWithStreamingResponse,
    AsyncReportsResourceWithStreamingResponse,
)
from .profiles import (
    ProfilesResource,
    AsyncProfilesResource,
    ProfilesResourceWithRawResponse,
    AsyncProfilesResourceWithRawResponse,
    ProfilesResourceWithStreamingResponse,
    AsyncProfilesResourceWithStreamingResponse,
)

__all__ = [
    "ReportsResource",
    "AsyncReportsResource",
    "ReportsResourceWithRawResponse",
    "AsyncReportsResourceWithRawResponse",
    "ReportsResourceWithStreamingResponse",
    "AsyncReportsResourceWithStreamingResponse",
    "ProfilesResource",
    "AsyncProfilesResource",
    "ProfilesResourceWithRawResponse",
    "AsyncProfilesResourceWithRawResponse",
    "ProfilesResourceWithStreamingResponse",
    "AsyncProfilesResourceWithStreamingResponse",
    "NewsResource",
    "AsyncNewsResource",
    "NewsResourceWithRawResponse",
    "AsyncNewsResourceWithRawResponse",
    "NewsResourceWithStreamingResponse",
    "AsyncNewsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .topic_enum import TopicEnum

__all__ = ["NewsListResponse", "Data", "Meta"]


class Data(BaseModel):
    id: str

    signal: str
    """Primary signal/headline"""

    timestamp: int
    """Unix timestamp (seconds)"""

    timestamp_iso: datetime = FieldInfo(alias="timestampISO")

    author: Optional[str] = None

    categories: Optional[List[str]] = None

    content: Optional[str] = None
    """Full context"""

    narrative_id: Optional[str] = FieldInfo(alias="narrativeId", default=None)

    sentiment: Optional[Literal["bullish", "bearish", "neutral"]] = None
    """Sentiment classification for news items"""

    sentiment_value: Optional[float] = FieldInfo(alias="sentimentValue", default=None)

    sources: Optional[List[str]] = None

    summary: Optional[str] = None
    """Short context summary"""

    tokens: Optional[List[str]] = None
    """Related tokens/assets"""

    tweet_url: Optional[str] = FieldInfo(alias="tweetUrl", default=None)


class Meta(BaseModel):
    count: Optional[int] = None

    limit: Optional[int] = None

    topics: Optional[List[TopicEnum]] = None


class NewsListResponse(BaseModel):
    data: List[Data]

    meta: Meta
